Description Usage Arguments Details Value Examples
Clean up a network adjacency matrix, filter the false-positive edges.
1 2 3 4 5 6 7 8 |
mat |
Input matrix, if it is a square matrix, the program assumes Input matrix, if it is a square matrix, the program assumes between nodes i and j. Elements of matrix should be non-negative. |
beta |
Scaling parameter, the program maps the largest absolute eigenvalue Scaling parameter, the program maps the largest absolute eigenvalue between 0 and 1. |
alpha |
fraction of edges of the observed dependency matrix to be kept in deconvolution process. |
control |
If FALSE, displaying direct weights for observed interactions, if 1, displaying direct weights for both observed and non-observed interactions. |
linear_mapping_before |
If TRUE, mat will be linearly mapped to be between 0 and 1 before deconvolution. |
linear_mapping_after |
If TRUE, result will be linearly mapped to be between 0 and 1 after deconvolution. |
Feizi, S.; Marbach, D.; Médard, M.; Kellis, M., Network deconvolution as a general method to distinguish direct dependencies in networks. Nature Biotechnology 2013, 31, 726–733.
mat_nd, Output deconvolved matrix (direct dependency matrix). Its components represent direct edge weights of observed interactions. Choosing top direct interactions (a cut-off) depends on the application and is not implemented in this code.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.